import { Http, Metadata } from '@zeedhi/core';
import { ApexChart } from '@zeedhi/common';

export class DashboardController {
    public openNewCall() {
        const data = { command: 'openNewCall' };
        this.sendMessage(data);
    }

    public productDeploy() {
        const data = { command: 'productDeploy' };
        this.sendMessage(data);
    }

    public openCustomizationFiles() {
        const data = { command: 'customizationFiles' };
        this.sendMessage(data);
    }

    public openDownloadVersionCard() {
        const data = { command: 'downloadVersionCard' };
        this.sendMessage(data);
    }

    public budgetChartClick() {
        const data = { command: 'budgetChart' };
        this.sendMessage(data);
    }

    public typeChartClick(event:any, chartContext:any, config:any) {
        const chart = Metadata.getInstance<ApexChart>('pie-type-chart');
        const data = {
            command: 'typeChart',
            type: chart.options.labels[config.dataPointIndex],
        };
        window.parent.postMessage({
            type: 'commandForCp',
            realData: data,
        }, window.location.ancestorOrigins[0]);
    }

    public labelChartClick(event:any, chartContext:any, config:any) {
        const chart = Metadata.getInstance<ApexChart>('pie-label-chart');
        const data = {
            command: 'labelChart',
            label: chart.options.labels[config.dataPointIndex],
        };
        window.parent.postMessage({
            type: 'commandForCp',
            realData: data,
        }, window.location.ancestorOrigins[0]);
    }

    public callNews() {
        const data = { command: 'callNews' };
        this.sendMessage(data);
    }

    public sendMessage(data:Object) {
        window.parent.postMessage({
            type: 'commandForCp',
            realData: data,
        }, window.location.ancestorOrigins[0]);
    }

	public async updateGraphicForFourMonth({ component }: any) {
		component.loading = true;
		const uri = '/callGraphicForFourMonth';
		const request = await Http.get(uri);
		const values = [request.data.dataset.callGraphicForFourMonth];
		const meses = [];
		const aberto = [];
		const emProcesso = [];
		const aguardando = [];
		const fechado = [];
		if (values.length > 0) {
			for (let i = 0; i < values[0].length; i += 1) {
				meses.push(values[0][i].MES);
				aberto.push(values[0][i].OPENED);
				emProcesso.push(values[0][i].INPROGRESS);
				aguardando.push(values[0][i].WAITING);
				fechado.push(values[0][i].CLOSED);
			}
		}
		const options = {
			series: [
				{
					name: 'Em aberto',
					data: aberto,
				},
				{
					name: 'Fechado',
					data: fechado,
				},
				{
					name: 'Em processo',
					data: emProcesso,
				},
				{
					name: 'Aguardando ação do cliente',
					data: aguardando,
				},
			],
			xaxis: {
				categories: meses,
			},
		};
		component.loading = false;
		component.updateChart(options);
	}

	public async countCallsByTypePieChart({ component }: any) {
		component.loading = true;
		const dashController = new DashboardController();
		const uri = '/countCallsByType';
		const request = await Http.get(uri);
		const values = [request.data.dataset.countCallsByType];
		const tipo = [];
		const quantidade = [];
		if (values.length > 0) {
			for (let i = 0; i < values[0].length; i += 1) {
				tipo.push(values[0][i].TYPE);
				quantidade.push(Number(values[0][i].QUANTITY));
			}
		}
		const newTipo = [];
		if (tipo.length > 0) {
			for (let i = 0; i < tipo.length; i += 1) {
				if (tipo[i] === 'I') {
					newTipo.push('Produto (Zeedhi: App, Browser, Mobile)');
				} else {
					newTipo.push('Produto (Delphi: Windows)');
				}
			}
		}
		const options = {
			labels: newTipo,
			series: quantidade,
			chart: {
				id: 'pie-chart',
				height: '100%',
				toolbar: {
					show: true,
				},
				events: {
					dataPointSelection: dashController.typeChartClick,
				},
			},
		};
		component.loading = false;
		component.updateChart(options);
	}

	public async countCallsByLabelPieChart({ component }: any) {
		component.loading = true;
		const dashController = new DashboardController();
		const uri = '/countCallsByLabel';
		const request = await Http.get(uri);
		const values = [request.data.dataset.countCallsByLabel];
		const chartData = [];
		if (values.length > 0) {
			for (let i = 0; i < values[0].length; i += 1) {
				chartData.push({
					x: values[0][i].LABEL,
					y: Number(values[0][i].QUANTITY),
				});
			}
		}
		const options = {
			series: [
				{
					data: chartData,
				},
			],
			chart: {
				id: 'pie-chart',
				height: 'auto',
				toolbar: {
					show: true,
				},
				events: {
					dataPointSelection: dashController.labelChartClick,
				},
			},
		};
		component.loading = false;
		component.updateChart(options);
	}
}
